@@ -1,7 +1,5 @@
-// -*- Mode: C++; indent-tabs-mode: nil; c-basic-offset: 4 -*-
-
 /*
- *  PaperBox - document-tile-view.cc
+ *  Paperbox - document-tile-view.cc
  *
  *  Copyright (C) 2007 Marko Anastasov
  *
@@ -27,7 +25,7 @@
 namespace paperbox {
 
     using std::vector;
-    using boost::shared_ptr;
+    using std::tr1::shared_ptr;
 
     typedef vector<shared_ptr<Document> > doc_vector;
 
